aboutsummaryrefslogtreecommitdiffhomepage
path: root/tensorflow/contrib/lite/kernels
diff options
context:
space:
mode:
authorGravatar Nupur Garg <nupurgarg@google.com>2018-09-26 18:26:51 -0700
committerGravatar TensorFlower Gardener <gardener@tensorflow.org>2018-09-26 18:31:32 -0700
commit51a6118e5bd85935b1d9ec0e68b92f1f98d14982 (patch)
tree5b3d7b469bebd510b678a2054c04311e4879fd09 /tensorflow/contrib/lite/kernels
parent78ee51bb8c41d616c01674e405784a51e4ec98a5 (diff)
Automated rollback of commit 82af048bc8c3c044c98a27b1c4c27bb62d4e4a14
PiperOrigin-RevId: 214705311
Diffstat (limited to 'tensorflow/contrib/lite/kernels')
-rw-r--r--tensorflow/contrib/lite/kernels/register.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/tensorflow/contrib/lite/kernels/register.cc b/tensorflow/contrib/lite/kernels/register.cc
index 9402105fa7..2f4b663a28 100644
--- a/tensorflow/contrib/lite/kernels/register.cc
+++ b/tensorflow/contrib/lite/kernels/register.cc
@@ -125,7 +125,7 @@ TfLiteStatus UnsupportedTensorFlowOp(TfLiteContext* context, TfLiteNode* node) {
context->ReportError(
context,
"Regular TensorFlow ops are not supported by this interpreter. Make sure "
- "you invoke the Flex delegate before inference.");
+ "you invoke the Eager delegate before inference.");
return kTfLiteError;
}
@@ -136,13 +136,13 @@ const TfLiteRegistration* BuiltinOpResolver::FindOp(tflite::BuiltinOperator op,
const TfLiteRegistration* BuiltinOpResolver::FindOp(const char* op,
int version) const {
// Return the NULL Op for all ops whose name start with "Flex", allowing
// the interpreter to delegate their execution.
- if (IsFlexOp(op)) {
+ if (IsEagerOp(op)) {
static TfLiteRegistration null_op{
nullptr, nullptr, &UnsupportedTensorFlowOp,
nullptr, nullptr, BuiltinOperator_CUSTOM,
- "Flex", 1};
+ "Eager", 1};
return &null_op;
}
return MutableOpResolver::FindOp(op, version);
@@ -136,13 +136,13 @@ const TfLiteRegistration* BuiltinOpResolver::FindOp(tflite::BuiltinOperator op,
const TfLiteRegistration* BuiltinOpResolver::FindOp(const char* op,
int version) const {
- // Return the NULL Op for all ops whose name start with "Flex", allowing
+ // Return the NULL Op for all ops whose name start with "Eager", allowing
// the interpreter to delegate their execution.